Class: Intrinio::OptionRealtime

Inherits:
Object
  • Object
show all
Defined in:
lib/intrinio-sdk/models/option_realtime.rb

Overview

An option contract gives the buyer of a contract the right to buy or sell a particular asset at a later date at an agreed upon price.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OptionRealtime

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 84

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.has_key?(:'ticker')
    self.ticker = attributes[:'ticker']
  end

  if attributes.has_key?(:'expiration')
    self.expiration = attributes[:'expiration']
  end

  if attributes.has_key?(:'expiration_time')
    self.expiration_time = attributes[:'expiration_time']
  end

  if attributes.has_key?(:'strike')
    self.strike = attributes[:'strike']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

end

Instance Attribute Details

#codeObject

The Intrinio Code for the Option.



19
20
21
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 19

def code
  @code
end

#expirationObject

The date on which the Option expires. The Option becomes invalid after this date and cannot be exercised.



25
26
27
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 25

def expiration
  @expiration
end

#expiration_timeObject

The date on which the Option expires. The Option becomes invalid after this date and cannot be exercised.



28
29
30
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 28

def expiration_time
  @expiration_time
end

#strikeObject

The strike price is the fixed price at which a derivative can be exercised, and refers to the price of the derivative’s underlying asset. In a call option, the strike price is the price at which the option holder can purchase the underlying security. For a put option, the strike price is the price at which the option holder can sell the underlying security.



31
32
33
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 31

def strike
  @strike
end

#tickerObject

The ticker symbol of the Security for the Option.



22
23
24
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 22

def ticker
  @ticker
end

#typeObject

The type of Option (put or call).



34
35
36
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 34

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 59

def self.attribute_map
  {
    :'code' => :'code',
    :'ticker' => :'ticker',
    :'expiration' => :'expiration',
    :'expiration_time' => :'expiration_time',
    :'strike' => :'strike',
    :'type' => :'type'
  }
end

.swagger_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 71

def self.swagger_types
  {
    :'code' => :'String',
    :'ticker' => :'String',
    :'expiration' => :'Date',
    :'expiration_time' => :'DateTime',
    :'strike' => :'Float',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
149
150
151
152
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      code == o.code &&
      ticker == o.ticker &&
      expiration == o.expiration &&
      expiration_time == o.expiration_time &&
      strike == o.strike &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 190

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Intrinio.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 256

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 169

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 156

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



162
163
164
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 162

def hash
  [code, ticker, expiration, expiration_time, strike, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 118

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 236

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



242
243
244
245
246
247
248
249
250
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 242

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



230
231
232
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 230

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
129
# File 'lib/intrinio-sdk/models/option_realtime.rb', line 125

def valid?
  type_validator = EnumAttributeValidator.new('String', ["put", "call"])
  return false unless type_validator.valid?(@type)
  return true
end